@@ -16,7 +16,7 @@ test_that("default ggplot2 error",{
   p <- ggplot(df, aes(y = temperature)) +
     geom_line(aes(x = date)) +
     geom_histogram(orientation = "y",binwidth = 0.5)
-  expect_error(ggplot_build(p), regexp = "date_trans works with objects of class Date only")
+  expect_error(ggplot_build(p), regexp = "works with objects of class <Date> only")
 })
 
 test_that("ggside work-around works",{
@@ -24,7 +24,7 @@ test_that("ggside work-around works",{
     geom_line() +
     geom_point(aes(color = month_name))
   p_yside <- p + geom_ysidehistogram(bins = 30)
-  expect_error(ggplot_build(p_yside), regexp = "date_trans works with objects of class Date only")
+  expect_error(ggplot_build(p_yside), regexp = "works with objects of class <Date> only")
   p_yside <- p_yside + scale_ysidex_continuous()
   expect_doppelganger("date_x_yside", p_yside)
   p_xside <- p + geom_xsidehistogram(bins = 30) + scale_xsidey_continuous(trans = "log10")
